@@ -177,13 +177,7 @@ class File(object):
                 http_response = self._put(url=url, data=data, headers=headers)
             http_response.raise_for_status()
         except Exception as err:
-            print({
-                'url': url,
-                'info_id': info_id,
-                'headers': headers,
-                'http_response': http_response,
-            })
-            # content = http_response.content
-            # print(f'Error occurred when put object: {err}, {content}, {traceback.format_exc()}')
+            content = http_response.content
+            print(f'Error occurred when put object: {err}, {content}, {traceback.format_exc()}')
             return False
         return True
